#
# spec file for package systemd-presets-branding-MicroOS
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define generic_name systemd-presets-branding

Name:           systemd-presets-branding-MicroOS
Version:        20230214
Release:        2.5
Summary:        Systemd default presets for openSUSE MicroOS
License:        MIT
Group:          System/Base
Source0:        50-default-MicroOS.preset
Source1:        50-default-MicroOS-user.preset
BuildRequires:  systemd-presets-branding-openSUSE
BuildRequires:  pkgconfig(systemd)
#!BuildIgnore:  systemd-presets-branding
Requires:       systemd-presets-common-SUSE
PreReq:         coreutils
# systemd-presets-common-SUSE provides
Requires(pre):  systemd-presets-common-SUSE
Supplements:    packageand(systemd:branding-MicroOS)
Conflicts:      systemd-presets-branding
Provides:       systemd-presets-branding = %{version}
Obsoletes:      systemd-presets-branding-CAASP < 15.1
BuildArch:      noarch

%description
Default presets for systemd on openSUSE MicroOS

%prep
%setup -q -T -c

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-preset

install -m644 %{SOURCE0}  %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m644 %{SOURCE1}  %{buildroot}%{_prefix}/lib/systemd/user-preset/
# Copy default presets and script
install -m644 %{_prefix}/lib/systemd/system-preset/90-default-openSUSE.preset %{buildroot}%{_prefix}/lib/systemd/system-preset/

%pre
# On initial installation, branding-preset-states does not yet exist,
# which is why we also check for the file to be present/executable
if [ $1 -gt 1 -a -x %{_prefix}/lib/%{generic_name}/branding-preset-states ] ; then
        #
        # Save the old state so we can detect which package have its
        # default changed later.
        #
        # Note: the old version of the script is used here.
        #
        %{_prefix}/lib/%{generic_name}/branding-preset-states save
        %{_prefix}/lib/%{generic_name}/branding-preset-states save user
elif [ $1 -eq 1 ]; then
  touch /run/rpm-%{name}-preset-all
fi

%post
if [ $1 -gt 1 ] ; then
        #
        # Now that the updated presets are installed, find the ones
        # that have been changed and apply "systemct preset" on them.
        #
        %{_prefix}/lib/%{generic_name}/branding-preset-states apply-changes
        %{_prefix}/lib/%{generic_name}/branding-preset-states apply-changes user
fi

%posttrans
if [ -f /run/rpm-%{name}-preset-all ]; then
  # Enable all services, which were installed before systemd
  # Don't disable services, since this would disable the
  # complete network stack.
  systemctl preset-all --preset-mode=enable-only
  systemctl preset-all --preset-mode=enable-only --global
fi
rm -f /run/rpm-%{name}-preset-all

%files
%defattr(-,root,root)
%{_prefix}/lib/systemd/system-preset/*
%{_prefix}/lib/systemd/user-preset/50-default-MicroOS-user.preset

%changelog
* Tue Mar 28 2023 Thorsten Kukuk <kukuk@suse.com>
- Remove tallow (package got dropped long ago)
- Enable lastlog2-import
* Tue Feb 14 2023 Richard Brown <rbrown@suse.com>
- Correct spelling of transactional-update-notifier.service in
  50-default-MicroOS-user.preset
- 20230214
* Mon Jan 30 2023 Richard Brown <rbrown@suse.com>
- Introduce 50-default-MicroOS-user.preset to allow Systemd user
  units for MicroOS users
- Add transactional-update-notifier Systemd user unit to default
  user preset. This will allow MicroOS Desktop users to have
  Desktop notifications about transactional updates either
  succeeding or failing. The D-Bus service in use have been audited
  already (boo#1206163).
- 20230130
* Wed Apr 22 2020 Richard Brown <rbrown@suse.com>
- Enable container-image-prune.timer by default
* Mon Mar 23 2020 Richard Brown <rbrown@suse.com>
- Enable kubelet by default (as expected by kubeadm) [boo#1167369]
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Mon Mar  4 2019 kukuk@suse.de
- Obsolete old CaaSP version to fix migration
* Tue Feb 19 2019 kukuk@suse.de
- Make MicroOS specific (remove CaaSP specific services)
* Mon Feb 18 2019 kukuk@suse.de
- Enable tallow by default.
* Tue Sep 25 2018 kukuk@suse.de
- Enable update-checker-migration.timer to check for new product
  versions [bsc#1109777].
* Fri Apr 20 2018 kukuk@suse.de
- Enable create-dirs-from-rpmdb.service for transactional-updates
* Thu Mar  8 2018 dimstar@opensuse.org
- Also drop 99-default-disable.preset: the default preset to
  disable all not-explicitly listed services is part of
  systemd-presets-common-SUSE.
* Wed Mar  7 2018 dimstar@opensuse.org
- FATE#322139: split out common service configuration from branding
  presets:
  + Copy only the %%theme specific file from
    systemd-preset-branding-theme into our file list; the rest is
    brought in as part of dependencies.
  + Require the new systemd-presets-common-SUSE package, also as
    Requoires(pre), as it contains the executables used.
* Tue Jan 16 2018 kukuk@suse.de
- Enable man-db-create.service if installed
* Tue Dec 12 2017 kukuk@suse.de
- Copy new default-SUSE.preset
- Cleanup 70-default-CAASP.preset
* Mon Dec 11 2017 kukuk@suse.de
- If we do a fresh installation, call systemctl preset-all in the
  %%posttrans section. Some services need to be installed before
  systemd or do not strictly require systemd, so systemd would only
  be installed after them and the systemd units of this package
  never enabled.
* Fri Dec  8 2017 kukuk@suse.com
- Fix %%pre/%%post preset calls
- Copy branding-preset-states script from main branding package
* Thu Aug  3 2017 kukuk@suse.de
- Fix building on SLE15
* Tue Jun 20 2017 kukuk@suse.de
- Enable ca-ceertificates.{path,service} by default
* Mon May 29 2017 kukuk@suse.de
- Enable apparmor by default
* Tue May  2 2017 kukuk@suse.de
- Workaround broken util-linux fixes for [bsc#1029775]
* Tue Apr 18 2017 kukuk@suse.de
- Enable adjust-cloud-cfg by default
* Wed Apr 12 2017 kukuk@suse.de
- Enable setup-salt-minion service by default
* Wed Apr 12 2017 kukuk@suse.de
- Enable audit daemon by default
* Tue Apr  4 2017 kukuk@suse.de
- Container-feeder is now enabled by YaST2
* Mon Apr  3 2017 kukuk@suse.de
- Enable health-checker.service per default
* Tue Mar 28 2017 kukuk@suse.de
- Workaround for bad idea to remove systemd macros in factory why
  other products still depend on them.
* Fri Mar 10 2017 kukuk@suse.de
- Add container-feeder.service
* Fri Jan 20 2017 kukuk@suse.de
- Adjust to make workable with SLE and openSUSE
* Tue Jan 17 2017 kukuk@suse.de
- Enable cloud-init services
* Sat Jan 14 2017 kukuk@suse.de
- Rename from casp to caasp
* Thu Dec 15 2016 kukuk@suse.de
- Remove snapper again
- Add sshd, since installer has no configuration dialog anymore
  for this
* Fri Nov 25 2016 kukuk@suse.de
- Enable issue-generator
* Wed Nov 23 2016 kukuk@suse.de
- Enable snapper-timeline.timer and snapper-cleanup.timer by
  default
* Sat Nov 19 2016 kukuk@suse.de
- Enable rebootmgr.service by default
* Wed Nov 16 2016 kukuk@suse.de
- Enable logrotate and transactional-update by default
* Tue Nov 15 2016 kukuk@suse.de
- Initial version
